Products
and Services Support
and Docs Training Partner Programs About Red
Hat
  download storecart
red hat logo
redhat.comredhat network

Red Hat Documentation

Kickstart-Befehle

Kickstart-Befehle

Die folgenden Befehle können in einer Kickstart-Datei verwendet werden.

auth - Sicherheitsprüfungsoptionen

auth (obligatorisch)

Richtet die Sicherheitsprüfungsoptionen für das System ein. Dieser Befehl ähnelt dem Befehl authconfig , der nach der Installation ausgeführt werden kann. Standardmäßig wird statt Shadow-Paßwörtern die normale Verschlüsselung verwendet.

--enablemd5

Verwenden von MD5-Verschlüsselung für die Benutzerpaßwörter

--enablenis

Aktiviert die NIS-Unterstützung. Standardmäßig verwendet --enablenis die nächste Domäne, die im Netzwerk gefunden wird. Eine Domäne sollte fast immer manuell eingestellt werden (über --nisdomain).

--nisdomain

NIS-Domänenname für NIS-Dienste.

--nisserver

Server für NIS-Dienste (Standardvorgabe Broadcast).

--useshadow

Shadow-Paßwörter verwenden.

clearpart - Löschen von Partitionen auf Basis des Partitionstyps

clearpart (optional)

Enfernt Partitionen, bevor neue Partitionen erstellt werden. Standardmäßig werden keine Partitionen entfernt.

--linux

Löscht Linux-Partitionen (Typ 0x82, 0x83 und 0xfd [RAID])

--all

Löscht alle Partitionen vom System.

device --opts

device (optional)

Auf den meisten PCI-Systemen sucht das Installationsprogramm automatisch nach Ethernet- und SCSI-Karten. Auf älteren Systemen und einigen PCI-Systemen muß Kickstart jedoch beim Finden der richtigen Geräte unterstützt werden. Der Befehl device weist Anaconda an, Zusatzmodule zu installieren. Die Befehlssyntax ist wie folgt:

device <Typ>
<Modulname> --opts
<Optionen>
	    

<Typ> sollte "scsi" oder "eth" sein, <Modulname> ist der Name des zu installierenden Kernelmoduls.

--opts

Optionen, die an das Kernelmodul übergeben werden sollen. Beachten Sie, daß durch das Einschließen in Anführungszeichen mehrere Optionen übergeben werden können. Beispiel:

--opts "aic152x=0x340 io=11"
		    

driverdisk

driverdisk (optional)

Während der Kickstart-Installation können Treiberdisketten verwendet werden, indem der Inhalt einer Treiberdiskette in das Root-Verzeichnis einer Partition der Systemfestplatte kopiert wird. Mit dem Befehl driverdisk wird dem Installationsprogramm mitgeteilt, wo sich diese Treiber befinden.

driverdisk <Partition> [--type <FS-Typ>]
	    

<Partition> ist die Partition, in der sich die Treiberdiskette befindet.

--type

Dateisystemtyp (z.B. VFAT oder ext2).

install

install (optional)

Weist das System an, ein neues System zu installieren, anstatt ein vorhandenes System zu aktualisieren. Dies ist der Standardmodus.

Installationsmethoden

Zur Angabe, welcher Kickstart-Typ ausgeführt werden soll, muß einer dieser drei Befehle verwendet werden:

NFS

Installation vom NFS-Server.

  • --server <Server>

    Server, von dem aus die Installation vorgenommen werden soll (Rechnername oder IP).

  • --dir <Verzeichnis>

    Verzeichnis mit dem Red Hat Installationsverzeichnisbaum.

Beispiel:

nfs --server <Server> --dir <Verzeichnis>
	    
CD-ROM

Installation vom ersten CD-ROM-Laufwerk des Systems.

Beispiel:

cdrom
	    
harddrive

Installation von einem Red Hat Installationsverzeichnisbaum auf einem lokalen Laufwerk (VFAT oder ext2).

  • --partition <Partition>

    Partition, von der installiert werden soll (z.B. sdb2).

  • --dir <Verzeichnis>

    Verzeichnis mit dem Red Hat Installationsverzeichnisbaum.

Beispiel:

harddrive --partition <Partition> --dir <Verzeichnis>
	    

keyboard

keyboard (obligatorisch)

Zur Angabe des Typs der Systemtastatur. Hier die Liste der verfügbaren Tastaturen auf i386- und Alpha-Rechnern:

azerty, be-latin1, be2-latin1, fr-latin0, fr-latin1, fr-pc, fr,
wangbe, ANSI-dvorak, dvorak-l, dvorak-r, dvorak, pc-dvorak-latin1,
tr_f-latin5, trf, bg, cf, cz-lat2-prog, cz-lat2, defkeymap,
defkeymap_V1.0, dk-latin1, dk, emacs, emacs2, es, fi-latin1, fi,
gr-pc, gr, hebrew, hu101, is-latin1, it-ibm, it, it2, jp106,
la-latin1, lt, lt.l4, nl, no-latin1, no, pc110, pl, pt-latin1,
pt-old, ro, ru-cp1251, ru-ms, ru-yawerty, ru, ru1, ru2, ru_win,
se-latin1, sk-prog-qwerty, sk-prog, sk-qwerty, tr_q-latin5, tralt,
trf, trq, ua, uk, us, croat, cz-us-qwertz, de-latin1-nodeadkeys,
de-latin1, de, fr_CH-latin1, fr_CH, hu, sg-latin1-lk450,
sg-latin1, sg, sk-prog-qwertz, sk-qwertz, slovene
	    

Hier die Liste für SPARC-Rechner:

sun-pl-altgraph, sun-pl, sundvorak, sunkeymap, sunt4-es,
sunt4-no-latin1, sunt5-cz-us, sunt5-de-latin1, sunt5-es,
sunt5-fi-latin1, sunt5-fr-latin1, sunt5-ru, sunt5-uk, sunt5-us-cz
	    

language

lang (obligatorisch)

Gibt die Standardsprache für das installierte System an. Die angegebene Sprache wird während der Installation und zur Konfiguration aller sprachspezifischen Aspekte des installierten Systems verwendet. Wenn Sie zum Beispiel die Sprache Englisch einrichten möchten, lautet der entsprechende Eintrag in der Kickstart-Datei:

lang en_US
	    

Gültige Sprachcodes sind:

cs_CZ, en_US, fr_FR, de_DE, hu_HU, is_IS, id_ID, it_IT,
ja_JP.ujis, no_NO, pl_PL, ro_RO, sk_SK, sl_SI, es_MX,
ru_RU.KOI8-R, uk_UA
	    

lilo

lilo (obligatorisch)

Gibt an, wie der Bootloader auf dem System installiert werden soll. Standardmäßig wird LILO in den MBR der ersten Festplatte installiert. Wenn eine DOS-Partition gefunden wird, wird ein Dual-Boot-System installiert. (Das DOS/Windows-System wird gebootet, wenn am LILO:-Prompt dos durch den Benutzer eingegeben wird.)

--append <Parameter>

Angabe von Kernelparametern.

--linear

Verwendung der linearen LILO-Option. Dies dient nur der Abwärtskompatibilität. (Linear wird inzwischen als Standardeinstellung verwendet.)

--location

Gibt an, wo der LILO-Booteintrag gespeichert wird. Gültige Werte sind mbr (Standardvorgabe), partition (installiert den Bootloader in den ersten Sektor der Partition, in der sich der Kernel befindet) oder none, wodurch keine Bootloader installiert wird.

lilocheck

lilocheck (optional)

Wenn diese Angabe vorhanden ist, prüft das Installationsprogramm, ob LILO im MBR der ersten Festplatte abgelegt ist und startet das System neu, falls dies zutrifft - in diesem Fall wird keine Installation durchgeführt. Dadurch kann verhindert werden, daß Kickstart ein bereits installiertes System nochmals installiert.

mouse

mouse (obligatorisch)

Konfiguriert die Maus für das System, sowohl für den grafischen Modus als auch für den Textmodus. Optionen:

--device <Gerät>

Das Gerät, an dem die Maus angeschlossen ist (z.B. --device ttyS0).

--emulthree

Wenn das X Window System installiert ist, werden die linke und die rechte Maustaste zum Emulieren einer dritten Maustaste verwendet (bei Zwei-Tasten-Mäusen).

Nach den Optionen kann einer der folgenden Maustypen angegeben werden:

alpsps/2, ascii, asciips/2, atibm, generic, generic3,
genericps/2, generic3ps/2, geniusnm, geniusnmps/2,
geniusnsps/2, thinking, thinkingps/2, logitech,
logitechcc, logibm, logimman, logimmanps/2, logimman+,
logimman+ps/2, microsoft, msnew, msintelli, msintellips/2,
msbm, mousesystems, mmseries, mmhittab, sun, none
		    

Wenn der Befehl mouse ohne Argumente angegeben oder weggelassen wird, versucht das Installationsprogramm, die Maus selbst zu erkennen (funktioniert bei den meisten neueren Mäusen).

network

network (optional)

Konfiguriert Netzwerkinformationen für das System. Wenn diese Option nicht angegeben ist und die Kickstart-Installation keine Netzwerkfunktion erfordert (also keine Installation über NFS), wird keine Netzwerkfunktionalität für das System konfiguriert. Wenn die Installation Netzwerkfunktionalität erfordert, geht Anaconda davon aus, daß über eth0 und eine dynamische IP-Adresse (BOOTP/DHCP) installiert werden soll, und konfiguriert das fertig installierte System so, daß seine IP-Adresse automatisch bestimmt wird. Der Befehl network konfiguriert die Netzwerkinformationen für Netzwerk-Kickstart-Installationen und für das fertig installierte System.

--bootproto

Eine der folgenden Angaben: dhcp, bootp, oder static (Standardvorgabe DHCP, dhcp und bootp werden gleich behandelt). static muß angegeben werden, wenn statische IP-Informationen verwendet werden sollen.

--ip

IP-Adresse des zu installierenden Rechners.

--gateway

Standard-Gateway als IP-Adresse.

--nameserver

Primärer Nameserver als IP-Adresse.

--netmask

Netzmaske für das installierte System

Es gibt drei Möglichkeiten zur Netzwerkkonfiguration:

  • DHCP

  • BOOTP

  • statisch

Bei der DHCP-Methode bezieht das System die Informationen zur Netzwerkkonfiguration von einem DHCP-Serversystem. Die BOOTP-Methode benötigt entsprechend einen BOOTP-Server, der die Informationen zur Netzwerkkonfiguration liefert.

Bei der statischen Methode müssen Sie selbst alle erforderlichen Informationen zum Netzwerk in die Kickstart-Datei eintragen. Diese Informationen sind statisch, d.h. sie werden während der Installation und auch nach der Installation verwendet.

Mit der folgenden Zeile weisen Sie ein System an, die Netzwerkkonfiguration über DHCP zu beziehen:

network --bootproto dhcp
	    

Entsprechend bestimmt die nächste Zeile für diese Aufgabe einen BOOTP-Server:

network --bootproto bootp
	    

Wenn Sie die statische Methode gewählt haben, ist die Zeile etwas komplexer, da Sie alle Konfigurationsinformationen auf einer Zeile angeben müssen. Die folgenden Angaben sind obligatorisch:

  • IP-Adresse

  • Netzmaske

  • IP-Adresse des Gateways

  • IP-Adresse des Nameservers

Hier ein Beispiel für eine statische Zeile:

network --bootproto static
--ip 10.0.2.15
--netmask 255.255.255.0
--gateway 10.0.2.254
--nameserver 10.0.2.1
	    

AnmerkungBitte beachten:
 

Die gesamte Netzwerkkonfiguration muß in einer Zeile untergebracht werden. Nur aus Gründen der besseren Lesbarkeit haben wir in diesem Beispiel Zeilenumbrüche eingefügt.

Beachten Sie bitte die folgenden Einschränkungen, die für die statische Methode gelten:

  • Alle statischen Informationen zur Netzwerkkonfiguration müssen in einer Zeile angegeben werden. Es ist nicht möglich, Zeilen z.B. mit Hilfe eines umgekehrten Schrägstrichs umzubrechen.

  • Sie können hier nur einen Nameserver angeben. Im Abschnitt %post der Kickstart-Datei (beschrieben in Abschnitt namens %post - Konfigurieren nach der Installation) können Sie jedoch bei Bedarf weitere Nameserver hinzufügen.

partition

part (obligatorisch für Installationen, bei Aktualisierungen ignoriert)

Erstellt auf dem System eine Partition. Die Partitionsvorgaben haben die Form:

	      
part <mntpoint>
--size	<size> [--grow] [--onpart
<partc>] [--ondisk
<disk>]
	    

Am <mntpoint> ist die Partition gemountet. Die Angaben müssen mit einer der folgenden Methoden gemacht werden:

/<mntpoint>

(z.B. /, /usr, /home)

swap

Die Partition wird als Swap-Bereich verwendet.

raid.<id>

Die Partition wird für Software-RAID verwendet (siehe Befehl raid weiter unten).

--size <size>

Legt die Mindestgröße der Partition fest

--grow

Die Partition wird an den verfügbaren Speicherplatz angepaßt (falls zutreffend).

--onpart <part>

Weist das Installationsprogramm an, die Partition auf dem bereits vorhandenen Gerät <part> anzulegen. partition /home --onpart hda1 legt zum Beispiel /home auf Gerät /dev/hda1 an, das bereits vorhanden sein muß.

--ondisk <disk>

Erzwingt die Erstellung der Partition auf einer speziellen Festplatte. --ondisk sdb legt die Partition zum Beispiel auf der zweiten Systemfestplatte an.

Alle erstellten Partitionen werden während des Installationsprozesses formatiert.

raid

raid (optional)

Erstellt ein Software-RAID-Gerät. Dieser Befehl hat die Form:

raid <mntpoint> --level
<level> --device
<mddevice><partitions*>
	    

Am <mntpoint> wird das RAID-Dateisystem gemountet. Bei / muß RAID Level 1 verwendet werden, es sei denn, es ist eine Boot-Partition vorhanden (/boot). In diesem Fall muß die /boot-Partition vom Typ Level 1 sein. Für den Typ der Root (/)-Partition kann jeder der verfügbaren Typen festgelegt werden. <partitions*> (* deutet an, daß mehrere Partitionen aufgeführt werden können) gibt die RAID-Bezeichnungen an, die zum RAID-Array hinzugefügt werden sollen.

--level <level>

Zu verwendender RAID-Level (0, 1 oder 5).

--device <mddevice>

Bezeichnung des zu verwendenden RAID-Gerätes (z.B. md0 oder m1). Für RAID-Geräte können die Bezeichnungen md0 bis md7 (und jede nur einmal) verwendet werden.

Hier ein Beispiel für die Erstellung einer Partition mit RAID Level 1 für / und RAID Level 5 für /usr. Dabei wird angenommen, daß im System drei SCSI-Festplatten vorhanden sind. Es werden außerdem drei Swap-Partitionen erstellt, auf jedem Laufwerk eine.

part raid.01 --size 60 --ondisk sda
part raid.02 --size 60 --ondisk sdb
part raid.03 --size 60 --ondisk sdc
	    
part swap --size 128 --ondisk sda
part swap --size 128 --ondisk sdb
part swap --size 128 --ondisk sdc
	    
part raid.11 --size 1 --grow --ondisk sda
part raid.12 --size 1 --grow --ondisk sdb
part raid.13 --size 1 --grow --ondisk sdc
	    
raid / --level 1 --device md0 raid.01 raid.02 raid.03
raid /usr --level 5 --device md1 raid.11 raid.12 raid.13
	    

reboot

reboot (optional)

Neustart nach fertiggestellter Installation (keine Argumente). Normalerweise zeigt Kickstart eine Meldung an und wartet darauf, daß der Benutzer zum Neustart eine Taste betätigt.

rootpw

rootpw (obligatorisch)

Verwendung: rootpw [--iscrypted] <Paßwort>

Setzt das Root-Paßwort auf das als Argument angegebene <Paßwort>.

--iscrypted

Wenn diese Angabe vorhanden ist, wird davon ausgegangen, daß das Paßwort-Argument bereits verschlüsselt ist.

skipx

skipx (optional)

Wenn diese Angabe vorhanden ist, wird auf dem installierten System X nicht konfiguriert.

timezone

timezone (obligatorisch)

timezone [--utc] <Zeitzone>

Die System-Zeitzone wird auf <Zeitzone> eingestellt. Es kann jede der in "timeconfig" aufgeführten Zeitzonen angegeben werden.

--utc

Wenn diese Angabe vorhanden ist, geht das System davon aus, daß die Hardware-Uhr auf UTC (Greenwich Mean)-Zeit eingestellt ist.

upgrade

upgrade (optional)

Weist das System an, ein vorhandenes System zu aktualisieren, statt ein neues System zu installieren.

xconfig

xconfig (optional)

Konfiguriert das X Window System. Wenn diese Option nicht angegeben wird, muß X während der Installation vom Benutzer manuell konfiguriert werden, falls X installiert wurde. Diese Option sollte nur verwendet werden, wenn X auf dem Endsystem installiert ist.

--noprobe

Keine Monitor-Erkennung.

--card <Karte>

Verwendung von Karte <Karte>. Der Kartenname muß in der Kartenliste in Xconfigurator enthalten sein. Wenn dieses Argument nicht angegeben wird, fragt Anaconda den PCI-Bus nach der Karte ab.

--monitor <mon>

Verwendung des Monitors <mon>. Die Monitorname muß in der Monitorliste in Xconfigurator enthalten sein. Diese Angabe wird ignoriert, wenn --hsync oder --vsync angegeben ist. Wenn keine Monitorinformationen angegeben sind, wird die Monitorerkennung über Plug-and-Play durchgeführt.

--hsync <sync>

Gibt die Horizontalfrequenz des Monitors an.

--vsync <sync>

Gibt die Bildwiederholrate des Monitors an.

--startxonboot

Verwendung eines grafischen Dialogfelds für die Anmeldung (Runlevel 5) für das installierte System.

zerombr - Initialisieren der Partitionstabelle

zerombr (optional)

Wenn "zerombr" angegeben wird und "yes" das einzige Argument ist, werden alle auf den Festplatten gefundenen ungültigen Partitionstabellen initialisiert. Dadurch wird der gesamte Inhalt der Festplatten mit ungültigen Partitionstabellen gelöscht. Verwendung:

zerombr yes

Es ist kein anderes Format möglich.

%packages - Auswählen der Pakete

Der Befehl %packages steht am Beginn eines Kickstart-Dateiabschnitts, in dem die zu installierenden Pakete aufgeführt sind (nur für Installationen, die Paketauswahl bei Aktualisierungen wird nicht unterstützt).

Pakete können als Komponenten oder als einzelne Paketnamen angegeben werden. Das Installationsprogramm definiert verschiedene Komponenten, in denen Pakete mit ähnlichen Funktionen zusammengefaßt sind. Eine Liste der Komponenten finden Sie in der Datei RedHat/base/comps auf jeder Red Hat Linux CD-ROM. Die Zeilen zur Angabe von Komponenten beginnen mit einer Zahl, gefolgt von einem Leerzeichen und dem Namen der Komponente. In dieser Komponente sind die einzelnen Komponenten Zeile für Zeile aufgelistet. Einzelpaketen ist keine Zahl vorangestellt.

Zusätzlich gibt es drei weitere Zeilentypen in der Datei comps:

Architekturspezifisch (alpha:, i386: und sparc64:)

Wenn ein Paketname mit einem Architekturtyp beginnt, muß nur der Paketname eingegeben zu werden, nicht der Architekturname. Beispiel:

Für i386: netscape-common Es muß nur der Teil netscape-common angegeben werden, damit dieses Paket installiert wird.

Zeilen mit vorangestelltem ?

Zeilen, die mit ? beginnen, gelten nur für das Installationsprogramm. Diese Zeilentypen brauchen Sie nicht zu beachten.

Zeilen, mit vorangestelltem --hide

Wenn ein Paketname mit --hide beginnt, muß nur der Paketname ohne --hide angegeben werden. Beispiel:

Bei --hide KDE Workstation muß nur der Teil KDE Workstation angegeben werden, um dieses Paket zu installieren.

Normalerweise reicht es aus, wenn Sie nur die gewünschten Komponenten und nicht die einzelnen Pakete angeben. Beachten Sie, daß die Basis-Komponente standardmäßig immer ausgewählt wird. Die Angabe im Abschnitt %packages ist daher nicht erforderlich.

Hier ein Beispiel für eine %packages-Auswahl:

%packages
@ Networked Workstation
@ C Development
@ Web Server
@ X Window System
bsd-games
      

Wie das Beispiel zeigt, werden die Komponenten zeilenweise angegeben. Die Zeilen werden mit dem Zeichen @ eingeleitet, gefolgt von einem Leerzeichen und dem vollständigen Namen der Komponente (aus der Datei comps). Einzelne Pakete werden ohne zusätzliche Zeichen eingetragen (im obigen Beispiel steht die Zeile bsd-games für ein einzelnes Paket).

AnmerkungBitte beachten:
 

Sie können mit Kickstart auch Workstation- und Server-Installation durchführen. Fügen Sie hierzu einfach eine der folgenden Zeilen in den Bereich %packages ein:

	@ Gnome Workstation
	@ KDE Workstation
	@ Server
      

%post - Konfigurieren nach der Installation

Sie können Befehle hinzufügen, die nach der abgeschlossenen Installation auf dem System ausgeführt werden. Dieser Abschnitt muß sich am Ende der Kickstart-Datei befinden und mit dem Befehl %post beginnen. Sie können im Abschnitt %post auf das Netzwerk zugreifen. Der Nameservice ist in dieser Phase allerdings noch nicht konfiguriert, so daß IP-Adressen verwendet werden müssen. Hier ein Beispiel für einen %post-Abschnitt:

%post
# Kommentar zu /etc/motd hinzufügen
echo "Kickstart-Installation `/bin/date`" > /etc/motd
# einen weiteren Nameserver hinzufügen
echo "Nameserver 10.10.0.2" >> /etc/resolv.conf
      

Dieser Abschnitt erstellt eine Message-of-the-day-Datei, die das Datum der Kickstart-Installation enthält und die Beschränkung des Befehls network auf "nur einen Nameserver" dadurch umgeht, daß ein weiterer Nameserver zu /etc/resolv.conf hinzugefügt wird.

AnmerkungBitte beachten:
 

Die nach der Installation ausgeführten Skripten werden in einer mit chroot-Umgebung ausgeführt. Daher ist zum Beispiel das Kopieren von Skripten oder RPMs vom Installationsmedium nicht möglich.

--nochroot

Damit können Befehle angegeben werden, die außerhalb der chroot-Umgebung ausgeführt werden sollen.

 

 


 
© 2001 Red Hat, Inc. All rights reserved.
About Red Hat  :  Legal statement  :  Privacy statement  :  Y2K statement  :  Contact Red Hat